/*****************************************************************************/
/* File       : privs.h                                                      */
/* Description: macros for privileged operations                             */
/* Author     : Peter Tobias, tobias@et-inf.fho-emden.de, tobias@linux.de    */
/*****************************************************************************/
/* This file is part of the implementation of the thesis                     */
/*                                                                           */
/*  Entwurf und Implementation eines Protokoll Analysators fuer              */
/*  ISO 7498 konforme Netzwerke                                              */
/*                                                                           */
/*  (Design and implementation of a protocol analyzer for ISO 7498           */
/*   conforming networks)                                                    */
/*                                                                           */
/* Copyright 1996 by Peter Tobias.  All rights reserved. This program is NOT */
/* free software; it may not be used or redistributed without permission.    */
/*****************************************************************************/

#ifndef _PRIVS_H
#define _PRIVS_H

#include <unistd.h>

uid_t real_uid, effective_uid;
gid_t real_gid, effective_gid;

/* drop root privileges (must be called before any other of the
   following macros) */
#define U_DROP_PRIVS { \
		real_uid = getuid(); \
		effective_uid = geteuid(); \
		real_gid = getgid(); \
		effective_gid = getegid(); \
		setreuid(effective_uid, real_uid); \
		setregid(effective_gid, real_gid); \
	}

/* execute a given block with root privileges */
#define PRIV_ROOT_START {\
		setreuid(real_uid, effective_uid); \
		setregid(real_gid, effective_gid); \

#define PRIV_ROOT_END \
		setreuid(effective_uid, real_uid); \
		setregid(effective_gid, real_gid); \
	}

/* turn back to root privileges. Use with care! */
#define PRIV_ROOT {\
		setreuid(real_uid, effective_uid); \
		setregid(real_gid, effective_gid); \
	}

#endif  /* _PRIVS_H_ */

